=== modified file 'Makefile'
--- Makefile	2009-07-07 20:59:15 +0000
+++ Makefile	2009-07-10 04:03:14 +0000
@@ -127,7 +127,8 @@
 # warning before the eggs directory is made.  The target for the eggs directory
 # is only there for deployment convenience.
 bin/buildout: download-cache eggs
-	$(PYTHON) bootstrap.py
+	$(PYTHON) bootstrap.py --ez_setup-source=ez_setup.py \
+		--download-base=download-cache/dist --eggs=eggs
 
 $(PY): bin/buildout versions.cfg
 	./bin/buildout configuration:instance_name=${LPCONFIG}

=== modified file 'bootstrap.py'
--- bootstrap.py	2009-06-01 21:28:01 +0000
+++ bootstrap.py	2009-07-10 04:03:14 +0000
@@ -11,41 +11,106 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-
-# NOTE TO LAUNCHPAD DEVELOPERS: This is a bootstrapping file from the
-# zc.buildout project, which we have hacked slightly: look for the string
-# "HACK" below.   See the docstring below for usage.
-
 """Bootstrap a buildout-based project
 
 Simply run this script in a directory containing a buildout.cfg.
 The script accepts buildout command-line options, so you can
 use the -c option to specify an alternate configuration file.
 
-$Id$
+$Id: bootstrap.py 101778 2009-07-10 00:55:19Z gary $
 """
 
-import os, shutil, sys, tempfile, urllib2
-
-tmpeggs = tempfile.mkdtemp()
-
-is_jython = sys.platform.startswith('java')
+import os, re, shutil, sys, tempfile, textwrap, urllib, urllib2
+
+# We have to manually parse our options rather than using one of the stdlib
+# tools because we want to pass the ones we don't recognize along to
+# zc.buildout.buildout.main.
+
+configuration = {
+    '--ez_setup-source': 'http://peak.telecommunity.com/dist/ez_setup.py',
+    '--version': '',
+    '--download-base': None,
+    '--eggs': None}
+
+helpstring = __doc__ + textwrap.dedent('''
+    This script recognizes the following options itself.  The first option it
+    encounters that is not one of these will cause the script to stop parsing
+    options and pass the rest on to buildout.  Therefore, if you want to use
+    any of the following options *and* buildout command-line options like
+    -c, first use the following options, and then use the buildout options.
+
+    Options: 
+      --version=ZC_BUILDOUT_VERSION
+                Specify a version number of the zc.buildout to use
+      --ez_setup-source=URL_OR_FILE
+                Specify a URL or file location for the ez_setup file.
+                Defaults to
+                %(--ez_setup-source)s
+      --download-base=URL_OR_DIRECTORY
+                Specify a URL or directory for downloading setuptools and
+                zc.buildout.  Defaults to PyPI.
+      --eggs=DIRECTORY
+                Specify a directory for storing eggs.  Defaults to a temporary
+                directory that is deleted when the bootstrap script completes.
+
+    By using --ez_setup-source and --download-base to point to local resources,
+    you can keep this script from going over the network.
+    ''' % configuration)
+match_equals = re.compile(r'(%s)=(\S*)' % ('|'.join(configuration),)).match
+args = sys.argv[1:]
+if args == ['--help']:
+    print helpstring
+    sys.exit(0)
+
+# defaults
+tmpeggs = None
+
+while args:
+    val = args[0]
+    if val in configuration:
+        del args[0]
+        if not args or args[0].startswith('-'):
+            print "ERROR: %s requires an argument."
+            print helpstring
+            sys.exit(1)
+        configuration[val] = args[0]
+    else:
+        match = match_equals(val)
+        if match and match.group(1) in configuration:
+            configuration[match.group(1)] = match.group(2)
+        else:
+            break
+    del args[0]
+
+for name in ('--ez_setup-source', '--download-base'):
+    val = configuration[name]
+    if val is not None and '://' not in val: # we're being lazy.
+        configuration[name] = 'file://%s' % (
+            urllib.pathname2url(os.path.abspath(os.path.expanduser(val))),)
+
+if (configuration['--download-base'] and
+    not configuration['--download-base'].endswith('/')):
+    # download base needs a trailing slash to make the world happy
+    configuration['--download-base'] += '/'
+
+if not configuration['--eggs']:
+    configuration['--eggs'] = tmpeggs = tempfile.mkdtemp()
+else:
+    configuration['--eggs'] = os.path.abspath(
+        os.path.expanduser(configuration['--eggs']))
+
+if configuration['--version']:
+    configuration['--version'] = '==' + configuration['--version']
 
 try:
     import pkg_resources
 except ImportError:
     ez = {}
-    # HACK: the next two logical lines have been hacked for Launchpad to make
-    # bootstrapping not get any files over the network.  This is useful for
-    # development because it speeds up the build and makes it possible to
-    # make a new branch when you don't have network access.  It is essential
-    # for deployment because we currently do not allow network access on PQM
-    # or our deployment boxes.
-    exec open('ez_setup.py').read() in ez
-    ez['use_setuptools'](
-        to_dir=tmpeggs,
-        download_base='file://%s/download-cache/dist/' % (os.getcwd(),),
-        download_delay=0)
+    exec urllib2.urlopen(configuration['--ez_setup-source']).read() in ez
+    setuptools_args = dict(to_dir=configuration['--eggs'], download_delay=0)
+    if configuration['--download-base']:
+        setuptools_args['download_base'] = configuration['--download-base']
+    ez['use_setuptools'](**setuptools_args)
 
     import pkg_resources
 
@@ -58,33 +123,38 @@
 else:
     def quote (c):
         return c
-
-cmd = 'from setuptools.command.easy_install import main; main()'
-ws  = pkg_resources.working_set
-
-if is_jython:
+cmd = [quote(sys.executable),
+       '-c',
+       quote('from setuptools.command.easy_install import main; main()'),
+       '-mqNxd',
+       quote(configuration['--eggs'])]
+
+if configuration['--download-base']:
+    cmd.extend(['-f', quote(configuration['--download-base'])])
+
+cmd.append('zc.buildout' + configuration['--version'])
+
+ws = pkg_resources.working_set
+env = dict(
+    os.environ,
+    PYTHONPATH=ws.find(pkg_resources.Requirement.parse('setuptools')).location)
+
+try:
     import subprocess
-    
-    assert subprocess.Popen([sys.executable] + ['-c', quote(cmd), '-mqNxd', 
-           quote(tmpeggs), 'zc.buildout'], 
-           env=dict(os.environ,
-               PYTHONPATH=
-               ws.find(pkg_resources.Requirement.parse('setuptools')).location
-               ),
-           ).wait() == 0
-
+except ImportError:
+    exitcode = os.spawnle(*([os.P_WAIT, sys.executable] + cmd + [env]))
 else:
-    assert os.spawnle(
-        os.P_WAIT, sys.executable, quote (sys.executable),
-        '-c', quote (cmd), '-mqNxd', quote (tmpeggs), 'zc.buildout',
-        dict(os.environ,
-            PYTHONPATH=
-            ws.find(pkg_resources.Requirement.parse('setuptools')).location
-            ),
-        ) == 0
+    # Jython can use subprocess but not spawn.  We prefer it generally.
+    exitcode = subprocess.Popen(cmd, env=env).wait()
+if exitcode != 0:
+    # we shouldn't need an error message because a failure
+    # should have generated a visible traceback in the subprocess.
+    sys.exit(exitcode)
 
-ws.add_entry(tmpeggs)
-ws.require('zc.buildout')
+ws.add_entry(configuration['--eggs'])
+ws.require('zc.buildout' + configuration['--version'])
 import zc.buildout.buildout
-zc.buildout.buildout.main(sys.argv[1:] + ['bootstrap'])
-shutil.rmtree(tmpeggs)
+args.append('bootstrap')
+zc.buildout.buildout.main(args)
+if tmpeggs is not None:
+    shutil.rmtree(tmpeggs)

=== modified file 'versions.cfg'
--- versions.cfg	2009-07-06 14:51:23 +0000
+++ versions.cfg	2009-07-10 04:03:14 +0000
@@ -29,12 +29,12 @@
 wsgi-fileserver = 0.2.7
 wsgi-jsonrpc = 0.2.8
 wsgi-xmlrpc = 0.2.7
-z3c.recipe.filetemplate = 2.0.2
+z3c.recipe.filetemplate = 2.1dev-r101784
 z3c.recipe.i18n = 0.5.3
 z3c.recipe.tag = 0.2.0
-zc.buildout = 1.2.1
+zc.buildout = 1.4.0dev-r101783
 zc.lockfile = 1.0.0
-zc.recipe.egg = 1.2.2
+zc.recipe.egg = 1.3.0dev-r101773
 ZConfig = 2.6.1
 zope.app.locales = 3.5.1
 zope.configuration = 3.6.0

